palettable: Color palettes for Python
=====================================

Description
-----------

Color palettes for Python

License
-------

Upstream Contact
----------------

https://pypi.org/project/palettable/

